source parray.tcl
source stooop.tcl
namespace import stooop::*

### check user defined cloning operation (see nested class version in 69.tcl)

# expected output:

## a::(1,x) = 0
## a::(2,x) = 1

## A::(3,x) = 0
## A::(4,x) = 1

class a {}
proc a::a {this} {
    set ($this,x) 0
}
proc a::a {this copy} {
    set ($this,x) [expr $($copy,x)+1]
}
new [new a]
printArrays a::

class A {
    proc A {this} {
        set ($this,x) 0
    }
    proc A {this copy} {
        set ($this,x) [expr $($copy,x)+1]
    }
}
new [new A]
printArrays A::
